# taguchi
A tool for optimising systems parameterised by environment variables, based on Taguchi/orthogonal array systems of experiments.

## Disclaimer
All that I know and understand about this technique is at best a lossy interpretation of [this Youtube video](https://www.youtube.com/watch?v=5oULEuOoRd0) by [@Nighthawkinlight](https://www.youtube.com/@Nighthawkinlight), and at worst a complete misunderstanding of the basic scientific method. The video does a better job at explaining than I can hope for, so go check it out to understand the background.

## Installation

## Usage
